"use client";

import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";
import {
  ResponsiveContainer,
  BarChart,
  Bar,
  XAxis,
  YAxis,
  Tooltip,
  Legend,
  PieChart,
  Pie,
  Cell,
  LineChart,
  Line,
} from "recharts";

// Define the expected data structure
interface ChartData {
  name: string;
  [key: string]: number | string;
}

interface ChartContainerProps {
  title: string;
  description?: string;
  type: "bar" | "line" | "pie";
  data: ChartData[];
  className?: string;
   // Add these new props
  dataKeys?: { 
    value?: string; 
    value2?: string; 
    value3?: string;
    name?: string;
  };
  legendNames?: {
    value?: string;
    value2?: string;
    value3?: string;
  };
}

// Default values for the data keys
const defaultDataKeys = {
  value: 'value',
  name: 'name'
};

export function ChartContainer({
  title,
  description,
  type,
  data,
  className,
  dataKeys = defaultDataKeys,
  legendNames = {}
}: ChartContainerProps) {
  const renderChart = () => {

    if (!data || data.length === 0) {
      return (
        <div className="h-[300px] flex items-center justify-center">
          <p className="text-muted-foreground">No data available</p>
        </div>
      );
    }

    switch (type) {
      case "bar":
       return (
          <ResponsiveContainer width="100%" height={300}>
            <BarChart data={data} margin={{ top: 20, right: 30, left: 20, bottom: 5 }}>
              <XAxis dataKey={dataKeys.name} />
              <YAxis />
              <Tooltip />
              <Legend />
               {dataKeys.value && data[0][dataKeys.value] !== undefined && (
              <Bar 
                dataKey={dataKeys.value} 
                fill="hsl(var(--chart-1))" 
                name={legendNames.value || dataKeys.value} 
              />
              )}
              {dataKeys.value2 && data[0][dataKeys.value2] !== undefined && (
                <Bar 
                  dataKey={dataKeys.value2} 
                  fill="hsl(var(--chart-2))" 
                  name={legendNames.value2 || dataKeys.value2} 
                />
              )}
              {dataKeys.value3 && data[0][dataKeys.value3] !== undefined && (
                <Bar 
                  dataKey={dataKeys.value3} 
                  fill="hsl(var(--chart-3))" 
                  name={legendNames.value3 || dataKeys.value3} 
                />
              )}
            </BarChart>
          </ResponsiveContainer>
        );
      case "line":
        return (
          <ResponsiveContainer width="100%" height={300}>
            <LineChart data={data} margin={{ top: 20, right: 30, left: 20, bottom: 5 }}>
              <XAxis dataKey="name" />
              <YAxis />
              <Tooltip />
              <Legend />
              <Line
                type="monotone"
                dataKey="value"
                stroke="hsl(var(--chart-1))"
                activeDot={{ r: 8 }}
              />
              {data[0]?.value2 && (
                <Line type="monotone" dataKey="value2" stroke="hsl(var(--chart-2))" />
              )}
              {data[0]?.value3 && (
                <Line type="monotone" dataKey="value3" stroke="hsl(var(--chart-3))" />
              )}
            </LineChart>
          </ResponsiveContainer>
        );
      case "pie":
        const COLORS = [
          "hsl(var(--chart-1))",
          "hsl(var(--chart-2))",
          "hsl(var(--chart-3))",
          "hsl(var(--chart-4))",
          "hsl(var(--chart-5))",
        ];
        return (
          <ResponsiveContainer width="100%" height={300}>
            <PieChart>
              <Pie
                data={data}
                cx="50%"
                cy="50%"
                labelLine={false}
                outerRadius={100}
                fill="#8884d8"
                dataKey="value"
                nameKey="name"
                label={({ name, percent }) => `${name}: ${(percent * 100).toFixed(0)}%`}
              >
                {data.map((entry, index) => (
                  <Cell key={`cell-${index}`} fill={COLORS[index % COLORS.length]} />
                ))}
              </Pie>
              <Tooltip />
              <Legend />
            </PieChart>
          </ResponsiveContainer>
        );
      default:
        return null;
    }
  };

  return (
    <Card className={className}>
      <CardHeader>
        <CardTitle>{title}</CardTitle>
        {description && <p className="text-sm text-muted-foreground">{description}</p>}
      </CardHeader>
      <CardContent>{renderChart()}</CardContent>
    </Card>
  );
}